@@ -7,7 +7,7 @@ try:
   from ..ks_bot_client.ks_bot_exceptions import LoggingInError
 except:
   from ks_bot_client.ks_bot_exceptions import LoggingInError
-
+  
 class Bot:
 
   def __init__(self, name:str, password:str):
@@ -24,6 +24,7 @@ class Bot:
 
     self.session_id = None
 
+    self.smith_activated = False
 
   def log_in(self):
     """
@@ -38,9 +39,7 @@ class Bot:
       if x.json()["returns"] == "User exist":
         self.session_id = x.json()['data']["id"]
         return True
-    except Exception as e: pass
-  
-    return False
+    except Exception: return False
 
   def run(self):
     """
@@ -49,16 +48,83 @@ class Bot:
     logged_in = self.log_in()
     
     if logged_in:
-      self.sio.on("connect", handler=self.connect)
-      self.sio.on("WelcomeMessage", handler=self._event_welcome_message)
-      self.sio.on("BotProcessReply", handler=self._event_bot_process_reply)
-      self.sio.on("Timer Over", handler=self._event_timer_over)
+      self.sio.on("connect", handler=self.__connect)
+      self.sio.on("WelcomeMessage", handler=self.__event_welcome_message)
+      self.sio.on("BotProcessReply", handler=self.__event_bot_process_reply)
+      self.sio.on("Timer Over", handler=self.__event_timer_over)
+      self.sio.on("Switch To Voice Assitant", handler=self.__event_activate_smith)
+      self.sio.on("Switch To Text Assitant", handler=self.__event_activate_ks_bot)
+      self.sio.on("SPEAK", handler=self.__event_bot_speak)
+      self.sio.on("Here is The News", handler=self.__event_news)
+      self.sio.on("Here is the Weather", handler=self.__event_weather)
       self.sio.connect("https://ksbot.kidssmit.com")
       #self.sio.wait()
     else:
       raise LoggingInError("There was a problem login you in")
 
-  def connect(self):
+  def weather(self, data):
+    """
+      This event runs whenever the server has weather report ready for you
+    """
+    pass
+    
+  def __event_weather(self, data):
+    """
+      Runs weather ready event
+    """
+    threading.Thread(target=self.weather, args=[data]).start()
+    
+  def news(self, data):
+    """
+      This event runs whenever server has the news ready for you
+    """
+    pass
+    
+  def __event_news(self, data):
+    """
+      Runs news event
+    """
+    threading.Thread(target=self.news, args=[data]).start()
+    
+  def __event_bot_speak(self, data):
+    """
+      Runs bot speak
+    """
+    threading.Thread(target=self.speak, args=[data["what_to_speak"]]).start()
+
+  def speak(self, what_to_speak):
+    """
+      This events runs when ever the server wants you to say something
+    """
+    pass
+    
+  def __event_activate_ks_bot(self, data):
+    """
+      Runs de-activate S.M.I.T.H
+    """
+    self.smith_activated = False
+    threading.Thread(target=self.de_activate_smith, args=[data]).start()
+
+  def de_activate_smith(self, data):
+    """
+      This events runs after S.M.I.T.H has been De-Activated and KS-BOT has been activated
+    """
+    pass
+
+  def __event_activate_smith(self, data):
+    """
+      Runs activate S.M.I.T.H event
+    """
+    self.smith_activated = True
+    threading.Thread(target=self.activate_smith, args=[data]).start()
+
+  def activate_smith(self, data):
+    """
+      This event runs after S.M.I.T.H has been activated
+    """
+    pass
+    
+  def __connect(self):
     print("Client Connected")
     self.sio.emit("launch_bot", {"session_id": self.session_id})
 
@@ -68,7 +134,7 @@ class Bot:
     """
     print("KS-BOT said 'welcome'")
 
-  def _event_welcome_message(self, data):
+  def __event_welcome_message(self, data):
     """
       Runs welcome message event
     """
@@ -80,7 +146,7 @@ class Bot:
     """
     print("KS-BOT said: ", data)
 
-  def _event_bot_process_reply(self, data):
+  def __event_bot_process_reply(self, data):
     threading.Thread(target=self.BotProcessReply, args=[data]).start() # Runs in thread so it won't disturb main program
 
   def TimerOver(self, data):
@@ -90,7 +156,7 @@ class Bot:
 
     print("KS-BOT said: Timer is over, Timer: ", data)
 
-  def _event_timer_over(self, data):
+  def __event_timer_over(self, data):
     threading.Thread(target=self.TimerOver, args=[data]).start() # Runs in thread so it won't disturb main program
 
   def send_command(self, command, timeZone=None, log=False):
